@@ -21,7 +21,7 @@
 #
 # Import the libraries needed in this program
 # Basic ones
-import PyQt4 
+# import PyQt4 
 from PyQt4 import QtCore, QtGui
 import sys
 
@@ -38,12 +38,12 @@ import gobject
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 import gn_cellinfo
-import gtk
+#import gtk
 
 #Threading imports!
-from threading import Thread
-import time
-gtk.gdk.threads_init()
+# from threading import Thread
+# import time
+# gtk.gdk.threads_init()
 
 
 
@@ -354,7 +354,6 @@ class Ui_MainWindow(object):
         gobject.idle_add(start_location, control)
 
         loop.run()
-
         
         # Set the GPS tabel text       
         self.lbl_Gps_Info.setText(var_g_GPS)
@@ -433,24 +432,33 @@ class Ui_MainWindow(object):
 # It has the commented out message boxes, will work on this later
     def updateTab1(self):
   
-        import hildon
-        import gtk     
+        #import hildon
+        #import gtk     
         
         #dialog = gtk.Dialog()
         #dialog.set_title("Updating... please wait")
         #dialog.show_all()
         #dialog.run()
         #hildon.hildon_gtk_window_set_progress_indicator(dialog, 1)
-
+        
         self.pushButton_hw.setEnabled(False)
-        Thread(target=self.updaterootfs()).start()
-        Thread(target=self.updateAccel()).start()
-        Thread(target=self.updateCPU()).start()
-        Thread(target=self.updateGPS()).start()
-        Thread(target=self.updateMaemoV()).start()
-        Thread(target=self.updateImage()).start()
-        Thread(target=self.updateBatt()).start()
-        Thread(target=self.Cellular()).start()
+        self.pushButton_hw.setText(".")
+        self.updaterootfs()
+        self.pushButton_hw.setText("..")
+        self.updateAccel()
+        self.pushButton_hw.setText("...")
+        self.updateCPU()
+        self.pushButton_hw.setText("....")
+        self.updateGPS()
+        self.pushButton_hw.setText(".....")
+        self.updateMaemoV()
+        self.pushButton_hw.setText("......")
+        self.updateImage()
+        self.pushButton_hw.setText(".......")
+        self.updateBatt()
+        self.pushButton_hw.setText("........")
+        self.Cellular()
+        self.pushButton_hw.setText("Update")
         self.pushButton_hw.setEnabled(True)
 
         
@@ -539,6 +547,7 @@ def on_error(control, error, user_data):
         print "Requested method is not allowed in offline mode"
     elif error == location.ERROR_SYSTEM:
         print "System error"
+        
 
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, partially commented by me
 # Moved out of the class by me
@@ -553,7 +562,7 @@ def on_changed(device, data):
             var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
             #print device.fix[4:6]
             #Seems to struggle with doing it once.... so do it 5 times to warm it up!
-        for i in range(1, 5):
+        for i in range(1, 4):
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
                 var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
         #if device.fix[1] & location.GPS_DEVICE_ALTITUDE_SET:
